@@ -14,7 +14,7 @@ my $result = GetOptions(
     "secret-key=s" => \$opts->{secret},
     "first-name=s" => \$opts->{first},
     "last-name=s"  => \$opts->{last},
-    "mail=s"       => \$opts->{email},
+    "email=s"       => \$opts->{email},
     "password=s"   => \$opts->{password},
     "group=s"      => \$opts->{group},
 );
